(async () => {

// Load Worker

openpgp.initWorker({ path: '/static/frontend/openpgp/openpgp.worker.min.js' });

// Define key details

const participant1_name = "Test";
const participant1_id = "test@rooms.kumi.test";
const participant1_passphrase = "super long and hard to guess secret";

const participant2_name = "More test";
const participant2_id = "test2@rooms.kumi.test";
const participant2_passphrase = "even longer and harder to guess secret";

const curve = "ed25519";

var participant1_options = {
    userIds: [{ name: participant1_name, email: participant1_id }],
    curve: curve,
    passphrase: participant1_passphrase
};

var participant2_options = {
    userIds: [{ name: participant2_name, email: participant2_id }],
    curve: curve,
    passphrase: participant2_passphrase
};  

// Generate key

const { privateKeyArmored: participant1_privkey, publicKeyArmored: participant1_pubkey } = await openpgp.generateKey(participant1_options);

const { privateKeyArmored: participant2_privkey, publicKeyArmored: participant2_pubkey } = await openpgp.generateKey(participant2_options);

// Read and decrypt keys

const { keys: [participant1_readkey] } = await openpgp.key.readArmored(participant1_privkey);
await participant1_readkey.decrypt(participant1_passphrase);

const { keys: [participant2_readkey] } = await openpgp.key.readArmored(participant2_privkey);
await participant2_readkey.decrypt(participant2_passphrase);

// Get public keys

const participant1_readpubkey = (await openpgp.key.readArmored(participant1_pubkey)).keys[0];
const participant2_readpubkey = (await openpgp.key.readArmored(participant2_pubkey)).keys[0];

// Encrypt message

const text = "This is encrypted text sent from participant 1 to participant 2.";

const { data: encrypted } = await openpgp.encrypt({
	message: openpgp.message.fromText(text),
	publicKeys: [participant2_readpubkey],
	privateKeys: [participant1_readkey]
});

console.log(encrypted);

// Decrypt message

const { data: decrypted, signatures: signatures } = await openpgp.decrypt({
	message: await openpgp.message.readArmored(encrypted),
	publicKeys: [participant1_readpubkey],
	privateKeys: [participant2_readkey]
});

console.log(decrypted);
console.log(await signatures[0].valid);

})();
